/* 
 * File: gmlbrowser.h
 *
 * Medialib search and playlist editor
 * Copyright (c) 2005-2007 Johannes Heimansberg
 *
 * requires GTK+ 2.6 or better and XMMS2
 *
 * Released under the GNU General Public License v2
 */

#ifndef __GMLBROWSER_H__
#define __GMLBROWSER_H__

#include <gtk/gtk.h>

struct _GMLBrowser
{
	GtkWidget    *frame, *table;
	GtkWidget    *button_refresh, *image_refresh;
	GtkWidget    *button_rehash,  *image_rehash;
	GtkWidget    *button_expand_all,   *image_expand_all;
	GtkWidget    *button_collapse_all, *image_collapse_all;
	GtkWidget    *list,  *scroll_widget;
	GtkWidget    *button_search;
	GtkTreeStore *ts;
};

#endif
